==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sq\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""
 ,""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  "Pajisja"
 ,"Pajisje"

]
, "Devices"
: "Pajisje"

, "Active Sync"
: "Sinkornizim aktiv"

, "Select a Device"
: "Zgjidhni një Pajisje"

, "No ActiveSync Device registered"
: "Nuk ka pajisje të sinkronizimit aktiv të regjistuara"

, "Set as {0} Filter"
: "Vendosni {0} si Filtër"

, "Resetted Sync Filter"
: "Filtra sinkron të rivendosur"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Filtri {0} për pajisjen \"{1}\" është tani \"{2}\""

, "resetted"
: "rivendosur"

, "Set Sync Filter"
: "Vendsoni Filtrin e Sinkronizimit"

, "Default Addressbook"
: "Blloku i paracaktuar i adresave"

, "The default addressbook to create new contacts in."
: "Blloku i paracaktuar i adresave ku do të krijohen kontaktet"

, "Default Calendar"
: "Kalendari i paracaktuar"

, "The default calendar to create new events in."
: "Kalendari i paracaktuar ku do "

, "Default Task List"
: "Lista e paracaktuar detyrave"

, "The default task list to create new tasks in."
: "Lista e paracaktuar e detyrave ku do të krijohen detyra të reja"

, "Default policy for new devices"
: "Politika e paracaktuar e veprimit për pajisjet e reja"

, "Enter the id of the policy to apply to newly created devices."
: "Vendosni ID e Linjës së veprimit që do aplikohet për pajisjet e reja të krijuara "

, "Disable Access Log"
: "Ç'aktivizo ditarin e hyrjeve"

, "Disable ActiveSync Access Log creation."
: "Ç'aktivizo krijimin e ditarit të hyrjeve të Sinkronizimit Aktiv"

, "Filter timeslot for emails"
: "Filtro distancën kohore për e-postën"

, "For how long in the past the emails should be synchronized."
: "Për sa kohë përpara duhet të sinkronizohen e-posta"

, "Filter timeslot for events"
: "Filtro distancën kohore për ngjarjet"

, "For how long in the past the events should be synchronized."
: "Për sa kohë përpara duhet të sinkronizohen ngjarjet"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Politika e paracaktuar e Veprimeve "

, "Default Policy installed during setup"
: "Politika e paracaktuar e veprimeve"

, "SyncDevice"
: ""

, "Device"
: "Pajisja"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Kalendari i paracaktuar"

, "The default calendar to create new events in."
: "Kalendari i paracaktuar ku do "

, "Default Task List"
: "Lista e paracaktuar detyrave"

, "The default task list to create new tasks in."
: "Lista e paracaktuar e detyrave ku do të krijohen detyra të reja"

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Pajisja"
 ,"Pajisje"

]
, "Devices"
: "Pajisje"

, "Active Sync"
: "Sinkornizim aktiv"

, "Select a Device"
: "Zgjidhni një Pajisje"

, "No ActiveSync Device registered"
: "Nuk ka pajisje të sinkronizimit aktiv të regjistuara"

, "Set as {0} Filter"
: "Vendosni {0} si Filtër"

, "Resetted Sync Filter"
: "Filtra sinkron të rivendosur"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Filtri {0} për pajisjen \"{1}\" është tani \"{2}\""

, "resetted"
: "rivendosur"

, "Set Sync Filter"
: "Vendsoni Filtrin e Sinkronizimit"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Politika e paracaktuar e Veprimeve "

, "Default Policy installed during setup"
: "Politika e paracaktuar e veprimeve"

, "Default policy for new devices"
: "Politika e paracaktuar e veprimit për pajisjet e reja"

, "Enter the id of the policy to apply to newly created devices."
: "Vendosni ID e Linjës së veprimit që do aplikohet për pajisjet e reja të krijuara "

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Ç'aktivizo ditarin e hyrjeve"

, "Disable ActiveSync Access Log creation."
: "Ç'aktivizo krijimin e ditarit të hyrjeve të Sinkronizimit Aktiv"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filtro distancën kohore për ngjarjet"

, "For how long in the past the events should be synchronized."
: "Për sa kohë përpara duhet të sinkronizohen ngjarjet"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""





, "Sync Device"
: ""

, "Device"
: "Pajisja"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
